@@ -243,8 +243,8 @@ class CortxJupyter(ContentsManager):
 def _key(context, path):
     print(path)
     print(path.lstrip('/'))
-    # return context.prefix + path.lstrip('/')
-    return context.prefix + path
+    return context.prefix + path.lstrip('/')
+    # return context.prefix + path
 
 
 
